# Changelog

## [0.3.0](https://github.com/uptick/datawarehouse/compare/0.2.36...v0.3.0) (2025-06-04)


### Features

* **rollforward:** add product expansion to rollforward ([948010a](https://github.com/uptick/datawarehouse/commit/948010a363990d98163666098fa5be10aef1a803))
* **subscriptionmanager:** add original subscription fields to summary ([b15594f](https://github.com/uptick/datawarehouse/commit/b15594feecbeb118e9e6974243d01875e7edf23b))
* **workforce:** add new server usage model ([7abddab](https://github.com/uptick/datawarehouse/commit/7abddab0a1e222dbe280fa56f29e179811923799))


### Bug Fixes

* **datawarehouse:** fix wording on ServerUsageMetric model ([ae12fc8](https://github.com/uptick/datawarehouse/commit/ae12fc8514d883592934b18b83fd3b332fcbf394))

## [0.2.32](https://github.com/uptick/datawarehouse/compare/0.2.31...v0.2.32) (2025-02-26)


### Bug Fixes

* **accounts:** fix datawarehouse models ([dd9a2a1](https://github.com/uptick/datawarehouse/commit/dd9a2a1310638e81f07a50dfcbbe2286a978d5d5))
